@@ -56,7 +56,7 @@ class PathzGSPath(PathzCFSPath):
         self._fileio = None
 
     def __new__(cls, *parts, **kwargs):
-        if cls is PathzGSPath or issubclass(PathzGSPath): 
+        if cls is PathzGSPath or issubclass(cls, PathzGSPath): 
             cls = cls._win_pathz if os.name == 'nt' else cls._posix_pathz
             cls = globals()[cls]
         self = cls._from_parts(parts, init=False)
